# arpes.utilities.conversion.forward module

**arpes.utilities.conversion.forward.convert\_coordinates\_to\_kspace\_forward(arr:
Union\[xarray.core.dataarray.DataArray,
xarray.core.dataset.Dataset\],**kwargs)\*\*

> Forward converts all the individual coordinates of the data array
> :param arr: :param kwargs: :return:

**arpes.utilities.conversion.forward.convert\_coordinates(arr:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
collapse\_parallel=False,**kwargs)\*\*
